==> redquicklib-1.3.0.tgz: package/lib/screens/login.js <==
import React, {
    Component
} from 'react';
// const FBSDK = require('react-native-fbsdk');
// const {
//     LoginButton,
// } = FBSDK;
import { connect } from 'react-redux';
import {
    Container,
    Header,
    Title,
    Content,
    Footer,
    FooterTab,
    Button,
    Icon,
    Left,
    Body,
    Right,
    Text,
    Spinner,
} from 'native-base';
import * as utils from '../util';
import { Colors } from '../colors';
import { Actions } from 'react-native-router-flux';
import {
    Image,
    PermissionsAndroid,
    Linking,
    StyleSheet, View, Dimensions
} from 'react-native';
var ReactNative = require('react-native');
var {
    AsyncStorage,
    Platform
} = ReactNative;
import service from '../service';
import * as UIA from '../actions/uiActions';
const ILA = UIA;
import * as Titles from '../titles';

import accountverificationservice from '../accountverificationservice';
var _s = service();
import * as Common from '../common'
const { width, height } = Dimensions.get('window');
const LOGIN_CHECKING_STATUS = 'LOGIN_CHECKING_STATUS';
const $_login = '$_login';
class Login extends Component {
    constructor(props) {
        super(props);
        this.state = {};
    }
    getAccessToken(evt) {
        if (evt && evt.url) {
            var accessToken = evt.url.split('access=')[1];
            return accessToken;
        }
    }
    //request permission to access photos 
    _requestPermission() {
        if (Platform.OS === 'android')
            return PermissionsAndroid.request(PermissionsAndroid.PERMISSIONS.ACCESS_FINE_LOCATION, {
                'title': 'Location Required',
                'message': 'In order to provider the best service, your location is required.'
            }).then(res => {
                if (res !== 'granted')
                    return me._requestPermission();
                return Promise.resolve();
            });
        return Promise.resolve();
    }
    componentDidMount() {
        var me = this;
        me._requestPermission().then(() => {
            me.props.loadApp().then(() => {
                var { state } = me.props;
                var onbearertoken = token => {
                    if (token) {
                        me.props.UI($_login, true);
                        _s.setBearerAccessToken(token);
                        return accountverificationservice.login().then(res => {
                            return new Promise((resolve, fail) => {
                                if (res) {
                                    var complete = () => {
                                        me.props.UI(LOGIN_CHECKING_STATUS, false);
                                        resolve();
                                        me.props.UI($_login, false);
                                    };
                                    me.props.loginProcess(token, complete, complete);
                                }
                                else {
                                    me.props.UI(LOGIN_CHECKING_STATUS, false)
                                    me.props.UI($_login, false);
                                    return AsyncStorage.removeItem('bearer-token');
                                }
                            })
                        }).catch(UIA.catchAnd((error) => {
                            if (error) {
                                console.log('User not logged in, ')
                                if (!me.unmounted) {
                                    me.props.UI($_login, false);
                                    me.props.UI(LOGIN_CHECKING_STATUS, false);
                                }
                            }
                        }));
                    }
                };

                // if (Platform.OS !== 'ios' && !UIA.Get(state, 'signed_out')) {

                //     Linking.getInitialURL().then((url) => {
                //         UIA.log('initial url');;
                //         if (url) {
                //             UIA.log(url);
                //             var accessToken = me.getAccessToken({ url });
                //             if (accessToken && !UIA.Get(state, 'skip_access_token')) {
                //                 onbearertoken(accessToken);
                //             }
                //             me.props.UI('skip_access_token', false);
                //         }
                //     }).catch(err => console.error('An error occurred', err));


                // }

                me.props.UI('skip_access_token', true);
                AsyncStorage.getItem(UIA.SIGNED_OUT).then(res => {
                    if (!res || !JSON.parse(res)) {
                        me.props.UI(LOGIN_CHECKING_STATUS, true)
                        return AsyncStorage.getItem('bearer-token').then(onbearertoken).catch(e => {
                            console.log(e);
                        }).then(() => {
                            if (!me.unmounted) {
                                me.props.UI(LOGIN_CHECKING_STATUS, false);
                            }
                        });
                    }
                });
                me.unmounted = false;

            })
        });
    }
    componentWillUnmount() {
        this.unmounted = true;
    }
    _signIn() {
    }
    render() {
        var me = this;
        var { state } = me.props;

        if (UIA.Get(state, LOGIN_CHECKING_STATUS) ||
            UIA.Get(state, $_login) ||
            UIA.Get(state, ILA.LOGGING_IN_PROCESS)) {
            return (
                <View style={Object.assign({}, Common.ListMenuStyle(), {
                    flex: 1,
                    flexDirection: 'column',
                    justifyContent: 'center',
                    alignItems: 'center',
                })}>
                    <Image style={{ resizeMode: 'contain', width: width - 20 }} source={require('./img/logo2.png')} />
                    <Spinner color={Common.TextColor()} />
                    {/* <View style={{ position: 'absolute', bottom: 0, width: width }}>
                        <Button onPress={() => {
                            Actions.SignOut();
                        }} full>
                            <Text>{Titles.Cancel}</Text>
                        </Button>
                    </View> */}
                </View>
            )
        }
        var btn_width = 170;
        return (
            <View style={Object.assign({}, Common.ListMenuStyle(), {
                flex: 1,
                flexDirection: 'column',
                justifyContent: 'center',
                alignItems: 'center',
            })}>
                <Image style={{ resizeMode: 'contain', width: width - 20 }} source={require('./img/logo2.png')} />
                <View style={{ padding: 3 }}>
                    <Button onPress={() => {
                        me.props.UI('signed_out', false);
                        me.props.UI(ILA.IDENTITY_PROVIDER, 'Google');
                        Actions.IdentityLogin();
                    }}
                        style={{ backgroundColor: '#dd4b39', width: btn_width }}>
                        <Icon name="logo-googleplus" />
                        <Text>Google Plus</Text>
                    </Button>
                </View>
                <View style={{ padding: 3 }}>
                    <Button
                        style={{ backgroundColor: '#4A67B7', width: btn_width }}
                        onPress={() => {
                            me.props.UI('signed_out', false);
                            me.props.UI(ILA.IDENTITY_PROVIDER, 'Facebook');
                            Actions.IdentityLogin();
                        }}>
                        <Icon name="logo-facebook">
                        </Icon>
                        <Text>Facebook</Text>
                    </Button>
                    <Text style={{ color: 'yellow' }}>{UIA.Get(state, 'URL_')}</Text>
                </View>
            </View>
        );
    }
}


const styles = ({
    container: Object.assign({}, StyleSheet.absoluteFillObject, {
        justifyContent: 'center'
    }),
    centerBtn: {
        alignSelf: 'center',
        margin: 10,
        width: 150
    }
});


export default connect(utils.mapStateToProps, utils.mapDispatchToProps)(Login);

==> redquicklib-1.289.0.tgz: package/lib/screens/login.js <==
import React, {
    Component
} from 'react';
// const FBSDK = require('react-native-fbsdk');
// const {
//     LoginButton,
// } = FBSDK;
import { connect } from 'react-redux';
import {
    Container,
    Header,
    Title,
    Content,
    Footer,
    FooterTab,
    Button,
    Icon,
    Left,
    Body,
    Right,
    Text,
    Spinner,
} from 'native-base';
import * as utils from '../util';
import { Colors } from '../colors';
import { Actions } from 'react-native-router-flux';
import {
    Image,
    PermissionsAndroid,
    Linking,
    StyleSheet, View, Dimensions
} from 'react-native';
var ReactNative = require('react-native');
var {
    AsyncStorage,
    Platform
} = ReactNative;
import service from '../service';
import * as UIA from '../actions/uiActions';
const ILA = UIA;
import * as Titles from '../titles';

import accountverificationservice from '../accountverificationservice';
var _s = service();
import * as Common from '../common'
const { width, height } = Dimensions.get('window');
const LOGIN_CHECKING_STATUS = 'LOGIN_CHECKING_STATUS';
const $_login = '$_login';
class Login extends Component {
    constructor(props) {
        super(props);
        this.state = {};
    }
    getAccessToken(evt) {
        if (evt && evt.url) {
            var accessToken = evt.url.split('access=')[1];
            return accessToken;
        }
    }
    //request permission to access photos 
    _requestPermission() {
        if (Platform.OS === 'android')
            return PermissionsAndroid.request(PermissionsAndroid.PERMISSIONS.ACCESS_FINE_LOCATION, {
                'title': 'Location Required',
                'message': 'In order to provider the best service, your location is required.'
            }).then(res => {
                if (res !== 'granted')
                    return me._requestPermission();
                return Promise.resolve();
            });
        return Promise.resolve();
    }
    componentDidMount() {
        var me = this;
        me._requestPermission().then(() => {
            me.props.loadApp().then(() => {
                var { state } = me.props;
                var onbearertoken = token => {
                    if (token) {
                        me.props.UI($_login, true);
                        _s.setBearerAccessToken(token);
                        return accountverificationservice.login().then(res => {
                            return new Promise((resolve, fail) => {
                                if (res) {
                                    var complete = () => {
                                        me.props.UI(LOGIN_CHECKING_STATUS, false);
                                        resolve();
                                        me.props.UI($_login, false);
                                    };
                                    me.props.loginProcess(token, complete, complete);
                                }
                                else {
                                    me.props.UI(LOGIN_CHECKING_STATUS, false)
                                    me.props.UI($_login, false);
                                    return AsyncStorage.removeItem('bearer-token');
                                }
                            })
                        }).catch(UIA.catchAnd((error) => {
                            if (error) {
                                console.log('User not logged in, ')
                                if (!me.unmounted) {
                                    me.props.UI($_login, false);
                                    me.props.UI(LOGIN_CHECKING_STATUS, false);
                                }
                            }
                        }));
                    }
                };

                // if (Platform.OS !== 'ios' && !UIA.Get(state, 'signed_out')) {

                //     Linking.getInitialURL().then((url) => {
                //         UIA.log('initial url');;
                //         if (url) {
                //             UIA.log(url);
                //             var accessToken = me.getAccessToken({ url });
                //             if (accessToken && !UIA.Get(state, 'skip_access_token')) {
                //                 onbearertoken(accessToken);
                //             }
                //             me.props.UI('skip_access_token', false);
                //         }
                //     }).catch(err => console.error('An error occurred', err));


                // }

                me.props.UI('skip_access_token', true);
                AsyncStorage.getItem(UIA.SIGNED_OUT).then(res => {
                    if (!res || !JSON.parse(res)) {
                        me.props.UI(LOGIN_CHECKING_STATUS, true)
                        return AsyncStorage.getItem('bearer-token').then(onbearertoken).catch(e => {
                            console.log(e);
                        }).then(() => {
                            if (!me.unmounted) {
                                me.props.UI(LOGIN_CHECKING_STATUS, false);
                            }
                        });
                    }
                });
                me.unmounted = false;

            })
        });
    }
    componentWillUnmount() {
        this.unmounted = true;
    }
    _signIn() {
    }
    render() {
        var me = this;
        var { state } = me.props;

        if (UIA.Get(state, LOGIN_CHECKING_STATUS) ||
            UIA.Get(state, $_login) ||
            UIA.Get(state, ILA.LOGGING_IN_PROCESS)) {
            return (
                <View style={Object.assign({}, Common.ListMenuStyle(), {
                    flex: 1,
                    flexDirection: 'column',
                    justifyContent: 'center',
                    alignItems: 'center',
                })}>
                    <Image style={{ resizeMode: 'contain', width: width - 20 }} source={this.props.logo} />
                    <Spinner color={Common.TextColor()} />
                    {/* <View style={{ position: 'absolute', bottom: 0, width: width }}>
                        <Button onPress={() => {
                            Actions.SignOut();
                        }} full>
                            <Text>{Titles.Cancel}</Text>
                        </Button>
                    </View> */}
                </View>
            )
        }
        var btn_width = 170;
        return (
            <View style={Object.assign({}, Common.ListMenuStyle(), {
                flex: 1,
                flexDirection: 'column',
                justifyContent: 'center',
                alignItems: 'center',
            })}>
                <Image style={{ resizeMode: 'contain', width: width - 20 }} source={this.props.logo} />
                <View style={{ padding: 3 }}>
                    <Button onPress={() => {
                        me.props.UI('signed_out', false);
                        me.props.UI(ILA.IDENTITY_PROVIDER, 'Google');
                        Actions.IdentityLogin();
                    }}
                        style={{ backgroundColor: '#dd4b39', width: btn_width }}>
                        <Icon name="logo-googleplus" />
                        <Text>Google Plus</Text>
                    </Button>
                </View>
                <View style={{ padding: 3 }}>
                    <Button
                        style={{ backgroundColor: '#4A67B7', width: btn_width }}
                        onPress={() => {
                            me.props.UI('signed_out', false);
                            me.props.UI(ILA.IDENTITY_PROVIDER, 'Facebook');
                            Actions.IdentityLogin();
                        }}>
                        <Icon name="logo-facebook">
                        </Icon>
                        <Text>Facebook</Text>
                    </Button>
                    <Text style={{ color: 'yellow' }}>{UIA.Get(state, 'URL_')}</Text>
                </View>
            </View>
        );
    }
}


const styles = ({
    container: Object.assign({}, StyleSheet.absoluteFillObject, {
        justifyContent: 'center'
    }),
    centerBtn: {
        alignSelf: 'center',
        margin: 10,
        width: 150
    }
});


export default connect(utils.mapStateToProps, utils.mapDispatchToProps)(Login);
